@@ -1,7 +1,7 @@
 from typing import TypeVar, Generic
 import json
 
-T = TypeVar("T")
+T = TypeVar("T", json, int, str, float, list, dict, tuple)
 
 
 class Parameter(Generic[T]):
